2021-10-25 Version: 1.0.9
- CreateDBCluster Support ElasticResourceIO.

2021-05-14 Version: 1.0.8
- Update CreateDBCluster.
- Update ModifyDBCluster.

2021-03-31 Version: 1.0.7
- Generated python 2019-03-15 for adb.

2021-03-12 Version: 1.0.6
- Supportd DescribeTableStatisticsRequest.

